==> entodicton-5.51.3.tgz: package/test.js <==
client = require('./client')
_ = require('lodash')

tests = require('./tests')
queries = tests.queries;
objects = tests.objects;
objects['newTank'] = () => { return { name: 'tank1', 'id': 'tank1id' } };
objects['newBuilding'] = () => { return { name: 'building1', 'id': 'building1id' } };
Config = require('./src/config')
//config_base = require('../../entodicton/demo/src/components/config')
config_base = require('../../entodicton/demo/src/components/config_base')
config_earn = require('../../entodicton/demo/src/components/config_earn')
config_food = require('../../entodicton/demo/src/components/config_food')
const config = new Config(config_base).add(config_earn).add(config_food);
config.set('objects', objects);
//config.set('generators', []);
//config.set('semantics', []);

key = '6804954f-e56d-471f-bbb8-08e3c54d9321'
server = '3.129.10.225'
port = 3000
//client.process(config, key, '184.67.27.82')

const matching = (actual, expected) => {
  if (!_.isEqual(actual, expected)) {
    console.log("Results do not match")
    console.log("Expected:\n");
    console.log(JSON.stringify(expected, null, 2));
    console.log("Actual:\n");
    console.log(JSON.stringify(actual, null, 2));
    return false;
  } 
  return true;
}

const doOne = (queries) => {
  if (queries.length == 0) {
    return
  }
  const {query, generated, results} = queries[0]
  config.set('utterances', [query])
  client.process(config, key, server, port)
    .then( (responses) => {
      if (matching(responses.results[0], results) && matching(responses.generated[0], generated)) {
        console.log(`Okay ${query}`);
        doOne(queries.slice(1))
      }
    })
    .catch( (error) => { 
      console.log(`Error ${query}`);
      console.log(error)
    })
}

doOne(queries)

/*
queries.forEach ( ({query, generated, results}) => {
  config['utterances'] = [query]
  client.process(config, key)
    .then( (responses) => {
      responses = JSON.parse(responses)
      if (!_.isEqual(responses.results[0], results)) {
        console.log("Results do not match")
        console.log("Expected:\n");
        console.log(JSON.stringify(results, null, 2));
        console.log("Actual:\n");
        console.log(JSON.stringify(responses.results[0], null, 2));
      } else {
        console.log(`Okay ${query}`);
      }
    })
    .catch( (error) => { 
      console.log(`Error ${query}`);
      console.log(error)
    })
});
*/

==> entodicton-5.51.99.tgz: package/test.js <==
client = require('./client')
_ = require('lodash')

tests = require('./tests')
queries = tests.queries;
objects = tests.objects;
objects['newTank'] = () => { return { name: 'tank1', 'id': 'tank1id' } };
objects['newBuilding'] = () => { return { name: 'building1', 'id': 'building1id' } };
Config = require('./src/config')
//config_base = require('../../entodicton/demo/src/components/config')
config_base = require('../../entodicton/demo/src/components/config_base')
config_earn = require('../../entodicton/demo/src/components/config_earn')
config_food = require('../../entodicton/demo/src/components/config_food')
const config = new Config(config_base).add(config_earn).add(config_food);
config.set('objects', objects);
//config.set('generators', []);
//config.set('semantics', []);

//key = '6804954f-e56d-471f-bbb8-08e3c54d9321'
//url = 'http://3.129.10.225'
key = '0686949c-0348-411b-9b4b-32e469f2ed85'
url = 'http://Deplo-Entod-RAEZEG9Q8WCT-1232911377.ca-central-1.elb.amazonaws.com'

port = 3000
//client.process(config, key, '184.67.27.82')

const matching = (actual, expected) => {
  if (!_.isEqual(actual, expected)) {
    console.log("Results do not match")
    console.log("Expected:\n");
    console.log(JSON.stringify(expected, null, 2));
    console.log("Actual:\n");
    console.log(JSON.stringify(actual, null, 2));
    return false;
  } 
  return true;
}

const doOne = (queries) => {
  if (queries.length == 0) {
    return
  }
  const {query, generated, results} = queries[0]
  config.set('utterances', [query])
  client.process(url, key, config)
    .then( (responses) => {
      if (true || matching(responses.results[0], results) && matching(responses.generated[0], generated)) {
        console.log(`Okay ${query} memory usage ${responses['memory_free_percent']}`);
        doOne(queries.slice(1))
      }
    })
    .catch( (error) => { 
      console.log(`Error ${query}`);
      console.log(error)
    })
}

doOne(queries)

/*
queries.forEach ( ({query, generated, results}) => {
  config['utterances'] = [query]
  client.process(config, key)
    .then( (responses) => {
      responses = JSON.parse(responses)
      if (!_.isEqual(responses.results[0], results)) {
        console.log("Results do not match")
        console.log("Expected:\n");
        console.log(JSON.stringify(results, null, 2));
        console.log("Actual:\n");
        console.log(JSON.stringify(responses.results[0], null, 2));
      } else {
        console.log(`Okay ${query}`);
      }
    })
    .catch( (error) => { 
      console.log(`Error ${query}`);
      console.log(error)
    })
});
*/
